/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*-  vi:set ts=8 sts=4 sw=4: */

/*
 Calcium Signal Analyser Vamp Plugin
 
 Transient detection and characterisation for calcium signals.
 
 Centre for Digital Music, Queen Mary University of London.
 This file copyright 2010-2011 Mathieu Barthet and QMUL.
 
 Based on the QM Vamp note onset detector plugin by Christian 
 Landone, Chris Duxbury, and Juan Pablo Bello.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
 published by the Free Software Foundation; either version 2 of the
 License, or (at your option) any later version.  See the file
 COPYING included with this distribution for more information.
 
 Version: 2
 */

#ifndef _CALCIUM_SIGNAL_ANALSYER_PLUGIN_H_
#define _CALCIUM_SIGNAL_ANALSYER_PLUGIN_H_

#include <vamp-sdk/Plugin.h>

using std::vector;

class CalciumSignalAnalyser : public Vamp::Plugin
{
public:
    CalciumSignalAnalyser(float inputSampleRate);
    virtual ~CalciumSignalAnalyser();

    bool initialise(size_t channels, size_t stepSize, size_t blockSize);
    void reset();

    InputDomain getInputDomain() const { return TimeDomain; } //input data are passed to the plugin in the time domain
	
    std::string getIdentifier() const;
    std::string getName() const;
    std::string getDescription() const;
    std::string getMaker() const;
    int getPluginVersion() const;
    std::string getCopyright() const;

    ParameterList getParameterDescriptors() const;
    float getParameter(std::string) const;
    void setParameter(std::string, float);

    ProgramList getPrograms() const;
    std::string getCurrentProgram() const;
    void selectProgram(std::string program);

    size_t getPreferredStepSize() const;
    size_t getPreferredBlockSize() const;
	size_t getMinChannelCount() const;
    size_t getMaxChannelCount() const;
	
    OutputList getOutputDescriptors() const;

    FeatureSet process(const float *const *inputBuffers,
                       Vamp::RealTime timestamp);

    FeatureSet getRemainingFeatures();

protected:
    
	float m_inputSampleRate;
	size_t m_blockSize;
	size_t m_stepSize;
	
	vector<float> data;
	vector<Vamp::RealTime> time;
	
    float m_sensitivity;
	float m_delta;
	float m_mfwindur;
	
	int processcounter;
};

#endif
